# Copyright (C) 2019 rerobots, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os.path
from setuptools import setup


with open('README.rst', 'rt') as fp:
    long_description = fp.read()


# Version of this package
MAJOR=0
MINOR=3
PATCH=0
devel=False

version = '{}.{}.{}'.format(MAJOR, MINOR, PATCH)
if devel:
    version += '.dev0'
with open('mistygrind/_version.py', 'w') as fp:
    fp.write('''"""This file was automatically generated by setup.py. Do not edit.
"""
__version__ = '{}'
'''.format(version))


setup(name='mistygrind',
      version=version,
      author='mistygrind contributors',
      author_email='q@rerobots.net',
      url='https://github.com/rerobots/mistygrind',
      description='a tool for static analysis of Misty skills and offboard Misty REST API clients',
      long_description=long_description,
      license='Apache-2.0',
      classifiers=['License :: OSI Approved :: Apache Software License',
                   'Development Status :: 4 - Beta',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6',
                   'Programming Language :: Python :: 3.7',
                   'Programming Language :: Python :: 3.8'],
      packages=['mistygrind'],
      package_data = {
          'mistygrind': [os.path.join('eslint_rules', '*.js')],
      },
      install_requires=['responses', 'aiohttp'],
      entry_points={'console_scripts': ['mistygrind = mistygrind.cli:main']}
      )
